#include "Gadget/Engine.h" //This file includes all the other engine files

int WINAPI WinMain (HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine, int nCmdShow)
{
	//Here I'll create an instance of "Core" and call it "G". You can of course name it anything you like, 
	//but keeping the name short is important because we will end up typing it a lot. If you type G followed by 
	//a period, you will see a drop down list of all the stuff the engine can do, well not all of it. There are 
	//several other support classes provided to load graphics, play sounds, and other stuff.
	Core G; //Create an instance of the game engine
	G.Window.SetSampleRate(4); //Renders the text with smoother edges
	G.Window.SetClearColor(0.0f, 0.3f, 0.6f); //Set the background color to dark blue-green
	G.Window.Open(); //This line of code creates a window.
	G.Window.SetTitle("Text!");//Write "Text!" in the window's title bar

	//Fonts are not part of the TextBox class because you might want more than one TextBox to share the same font.
	//Fonts load kinda slow, so try not to load too many of them.
	Font comic;
	comic.Load(G.Window.GetHDC(), "Comic Sans MS");

	//Notice that the TextBox's Init function needs the address of the engine, the address of a font, and the width
	//and height. Width and height specify the rectangular area that the text is allowed to fill. Text will automatically
	//wrap when a new line is needed. If there are more lines of text than the height has room for, text at the top
	//will be removed to make room for new text being added to the bottom. The textBox cannot be displayed before the init
	//function has been called.
	TextBox textBox1;
	textBox1.Init(&G, &comic, 800.0f, 90.0f);
	textBox1.SetScale(65.0f); //The scale can be set to any size you wish and is related to the letter height in pixels
	textBox1.SetText("This text box can't be edited.");
	textBox1.position = Vector2D(0.0f, 580.0f);//The position of the top left corner of the textBox
	textBox1.AlignCenter(); //Centers the text within the rectangular area

	//Notice that the second textBox is using the same font but it is set to a different scale
	TextBox textBox2;
	textBox2.Init(&G, &comic, 700.0f, 500.0f);
	textBox2.SetScale(55.0f);
	textBox2.SetText("This one can!");
	textBox2.AddNewLine(); //Starts a lew line
	textBox2.AddText("Type something and see!"); //Add some more text
	textBox2.position = Vector2D(50.0f, 500.0f);
	textBox2.editable = true; //This textBox will respond to keyboard input

	while(G.Window.IsOpen()) //Loop continuously as long as the engine is running
	{
		G.Renderer.BeginFrame(); //Clears the buffers
		G.Renderer.Render2D();   //Render a 2D scene

			/*
			You can check to see if a key is being pressed at any time using the standard key codes or by using characters. For 
			example, I could check to see if the letter B is pressed like this G.Keyboard.GetKeyPress(B).
			*/
			if(G.Keyboard.GetKeyHold(GLFW_KEY_ESC)) {G.Window.Close();}	//ESC key closes the window
			
			//Shader effects and blending will affect everything you render! So it's a good idea to turn them off 
			//when you're finished with them. In fact, some older video cards will run really slow if shaders are
			//active when the screen refreshes. It's a good idea to turn them off when you are finished rendering
			//your scene. Also do this before rendering text!
			Shader::Deactivate(); //Turns off blending and any active shader

			glColor3f(1.0f, 1.0f, 1.0f);//I want this text to be White
			textBox1.Step(); //Renders the text

			glColor3f(0.8f, 1.0f, 1.0f);//I want this text to be Cyan
			textBox2.Step(); //Render the text
			glColor3f(1.0f, 1.0f, 1.0f);//Always set the color back to white or it will color everything!

		G.Renderer.EndFrame(); //Finished rendering, display the result
	}
	return 0;
}			